@@ -813,30 +813,53 @@ def spl(
 
 
 def psd2time(
-    spec, ppc, fstart, fstop, df, winends=None, gettime=False, expand_method="interp"
+    spec,
+    fstart,
+    fstop,
+    *,
+    ppc=10,
+    df=None,
+    winends=None,
+    gettime=False,
+    expand_method="interp",
 ):
-    """
+    r"""
     Generate a 'random' time domain signal given a PSD specification.
 
     Parameters
     ----------
     spec : 2d ndarray or 2-element tuple/list
-        If ndarray, its columns are ``[Freq, PSD1, PSD2, ... PSDn]``.
+        If ndarray, it has two columns: ``[Freq, PSD]``.
         Otherwise, it must be a 2-element tuple or list, eg:
-        ``(Freq, PSD)`` where PSD is: ``[PSD1, PSD2, ... PSDn]``. In
-        the second usage, PSD can be 1d; in the first usage, PSD is
-        always considered 2d.
-    ppc : scalar
-        Points per cycle at highest (`fstop`) frequency; if < 2, it is
-        internally reset to 2.
+        ``(Freq, PSD)``.
     fstart : scalar
         Starting frequency in Hz
     fstop : scalar
         Stopping frequency in Hz
-    df : scalar
-        Frequency step to be represented in the time signal. If
+    ppc : scalar; optional
+        Points per cycle at highest (`fstop`) frequency; if < 2, it is
+        internally reset to 2. With `fstop`, determines the sample
+        rate: ``sr = ppc * fstop``.
+    df : scalar or None; optional
+        Serves two purposes: it is the frequency step between
+        sinusoids included in the time signal, and it also determines
+        the duration of the signal. If None, it is set to ``fstart /
+        100`` in order to have 100 cycles at the lowest frequency. If
+        input as a scalar value, it is taken as a hint and will be
+        internally adjusted lower as needed; see Notes section. If
         routine gives poor results, try refining `df`. If `df` is
-        greater than `fstart`, it is reset internally to `fstart`.
+        greater than `fstart`, it is reset internally to `fstart` (in
+        that case though, you'll only get 1 cycle at the lowest
+        frequency). Total duration of the signal: ``T = 1 / df`` (see
+        equations below for more details).
+
+        .. note::
+            `df` can be used to indirectly specify the number of
+            cycles desired at the lowest frequency (`fstart`). For
+            example, if ``fstart=5.0`` and you want to have 500 cycles
+            of the 5.0 Hz content, then use ``df=0.01``: ``fstart / df
+            == 500``.
+
     winends : None or dictionary; optional
         If None, :func:`pyyeti.dsp.windowends` is not
         called. Otherwise, `winends` must be a dictionary of arguments
@@ -856,15 +879,81 @@ def psd2time(
     -------
     sig : 1d ndarray
         The time domain signal with properties set to match input PSD
-        spectrum.
+        spectrum. Duration of signal: ``1 / df``.
     sr : scalar
-        The sample rate of the signal.
+        The sample rate of the signal (``ppc * fstop``)
     time : 1d ndarray; optional
         Time vector for the signal starting at zero with step of
-        ``1/sr``: ``time = np.arange(len(sig))/sr``
+        ``1.0 / sr``: ``time = np.arange(len(sig)) / sr``.
+
+    Notes
+    -----
+    The following outlines the equations used in this routine.
+
+    If :math:`df` is None: :math:`df = fstart / 100`.
+
+    If :math:`df` is greater than :math:`fstart`, it is reset to
+    :math:`fstart`:
+
+    .. math::
+        df = \min(df, fstart)
+
+    The total time of the signal :math:`T` is determined by the lowest
+    frequency cycle (at frequency :math:`df`):
+
+    .. math::
+        T = 1 / df
+
+    The number of points needed is determined by the number of cycles
+    at the highest frequency multiplied by the points/cycle
+    :math:`ppc`:
+
+    .. math::
+        N = \lceil {fstop \cdot ppc \cdot T} \rceil
+
+    The frequency step :math:`df` is reset to match :math:`N` (because
+    of the possible round-up in the last equation):
+
+    .. math::
+        df = fstop \cdot ppc / N
+
+    The final downward adjustment to :math:`df` is to make sure we hit
+    the :math:`fstart` frequency exactly:
+
+    .. math::
+        df = fstart / \lfloor fstart / df \rfloor
+
+    The frequency vector is defined by:
+
+    .. math::
+        f = [fstart, fstart+df, ...,
+        \lceil fstop / df \rceil \cdot df]
+
+    A sinusoid is to be defined at each of those frequencies, so we
+    need to compute an amplitude and phase for each.
+
+    The amplitude is determined by the magnitude of the PSD. Since a
+    "power spectral density" is really mean-square spectral density,
+    and since the mean-square value of a sinusoid is the amplitude
+    squared over 2, the amplitude of each sinusoid is computed by:
+
+    .. math::
+        amp(f) = \sqrt { 2 \cdot PSD(f) \cdot df }
+
+    The phase is determined by using pseudo-random deviates from a
+    uniform distribution:
+
+    .. math::
+        phase(f) = U(0, 2\pi)
+
+    The amplitude and phase are assembled together in a complex array
+    so that an inverse-FFT will give a real time signal matching the
+    desired mean-square profile defined by the input PSD.
 
     Raises
     ------
+    ValueError
+        If more than one PSD specification is input.
     ValueError
         On invalid setting for `expand_method`.
 
@@ -920,10 +1009,22 @@ def psd2time(
         >>> v = plt.axvline(35, color='black', linestyle='--')
         >>> v = plt.axvline(70, color='black', linestyle='--')
     """
+    _freq, _psd, npsds = proc_psd_spec(spec)
+    if npsds > 1:
+        raise ValueError(
+            "only a single PSD specification is currently allowed in "
+            f"`psd2time`, but {npsds} were provided"
+        )
+
+    if df is None:
+        df = fstart / 100
+
     if df > fstart:
         df = fstart
+
     if ppc < 2:
         ppc = 2
+
     # compute parameters
     # 1 cycle of lowest frequency defines length of signal:
     T = 1 / df  # number of seconds for lowest frequency cycle
@@ -935,13 +1036,13 @@ def psd2time(
     odd = N & 1
 
     # define constants
-    freq = np.arange(fstart, fstop + df / 2, df)
+    # freq = np.arange(fstart, fstop + df / 2, df)
+    freq = np.arange(fstart, fstop + df, df)  # 4/9/22
 
     # generate amp(f) vector
     if expand_method == "interp":
         speclevel = interp(spec, freq).ravel()
     elif expand_method == "rescale":
-        _freq, _psd, npsds = proc_psd_spec(spec)
         speclevel, *_ = rescale(_psd.ravel(), _freq, freq=freq)
     else:
         raise ValueError(
